.. -*- mode: rst -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:

.. _chap_design:

******
Design
******

The chapter described command API principles and the design of particular
subsystems in DataLad.

.. toctree::
   :maxdepth: 2

   dataset_argument
   log_levels
   drop
   python_imports
   miscpatterns
   exception_handling
   credentials
   url_substitution
